import "./chunk-EGRHWZRV.js";
import "./chunk-BZD7WB2Q.js";
import "./chunk-IBWMO6UG.js";
import {
  description_list_default
} from "./chunk-DJQHOO67.js";
import "./chunk-OHFV76U2.js";
import {
  TablePage
} from "./chunk-BOFJZWRL.js";
import "./chunk-VRCRCQLD.js";
import "./chunk-EEANTJCZ.js";
import "./chunk-O4CYWEUV.js";
import {
  TableColumn
} from "./chunk-KZUPUEAQ.js";
import "./chunk-K3AR7TXW.js";
import "./chunk-KP2VLRW5.js";
import "./chunk-EXVQ6V2P.js";
import {
  DEFAULT_CONFIG,
  EVENT_REFRESH,
  EventsApi,
  SystemTaskStatusEnum,
  getRelativeTime,
  n,
  t
} from "./chunk-AMC4UCMS.js";
import {
  ke,
  msg,
  str
} from "./chunk-XFT4DB4U.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/system-tasks/SystemTaskListPage.ts
var SystemTaskListPage = class extends TablePage {
  constructor() {
    super(...arguments);
    this.expandable = true;
    this.order = "name";
  }
  pageTitle() {
    return msg("System Tasks");
  }
  pageDescription() {
    return msg("Long-running operations which authentik executes in the background.");
  }
  pageIcon() {
    return "pf-icon pf-icon-automation";
  }
  searchEnabled() {
    return true;
  }
  static get styles() {
    return super.styles.concat(description_list_default);
  }
  async apiEndpoint() {
    return new EventsApi(DEFAULT_CONFIG).eventsSystemTasksList(
      await this.defaultEndpointConfig()
    );
  }
  columns() {
    return [
      new TableColumn(msg("Identifier"), "name"),
      new TableColumn(msg("Description")),
      new TableColumn(msg("Last run")),
      new TableColumn(msg("Status"), "status"),
      new TableColumn(msg("Actions"))
    ];
  }
  taskStatus(task) {
    switch (task.status) {
      case SystemTaskStatusEnum.Successful:
        return ke`<ak-label color=${"pf-m-green" /* Green */}>${msg("Successful")}</ak-label>`;
      case SystemTaskStatusEnum.Warning:
        return ke`<ak-label color=${"pf-m-orange" /* Orange */}>${msg("Warning")}</ak-label>`;
      case SystemTaskStatusEnum.Error:
        return ke`<ak-label color=${"pf-m-red" /* Red */}>${msg("Error")}</ak-label>`;
      default:
        return ke`<ak-label color=${"" /* Grey */}>${msg("Unknown")}</ak-label>`;
    }
  }
  renderExpanded(item) {
    return ke` <td role="cell" colspan="3">
                <div class="pf-c-table__expandable-row-content">
                    <dl class="pf-c-description-list pf-m-horizontal">
                        <div class="pf-c-description-list__group">
                            <dt class="pf-c-description-list__term">
                                <span class="pf-c-description-list__text">${msg("Duration")}</span>
                            </dt>
                            <dd class="pf-c-description-list__description">
                                <div class="pf-c-description-list__text">
                                    ${msg(str`${item.duration.toFixed(2)} seconds`)}
                                </div>
                            </dd>
                        </div>
                        <div class="pf-c-description-list__group">
                            <dt class="pf-c-description-list__term">
                                <span class="pf-c-description-list__text">${msg("Expiry")}</span>
                            </dt>
                            <dd class="pf-c-description-list__description">
                                <div class="pf-c-description-list__text">
                                    ${item.expiring ? ke`
                                              <pf-tooltip
                                                  position="top"
                                                  content=${(item.expires || /* @__PURE__ */ new Date()).toLocaleString()}
                                              >
                                                  ${getRelativeTime(item.expires || /* @__PURE__ */ new Date())}
                                              </pf-tooltip>
                                          ` : msg("-")}
                                </div>
                            </dd>
                        </div>
                        <div class="pf-c-description-list__group">
                            <dt class="pf-c-description-list__term">
                                <span class="pf-c-description-list__text">${msg("Messages")}</span>
                            </dt>
                            <dd class="pf-c-description-list__description">
                                <div class="pf-c-description-list__text">
                                    <ak-log-viewer .logs=${item?.messages}></ak-log-viewer>
                                </div>
                            </dd>
                        </div>
                    </dl>
                </div>
            </td>
            <td></td>
            <td></td>`;
  }
  row(item) {
    return [
      ke`<pre>${item.name}${item.uid ? `:${item.uid}` : ""}</pre>`,
      ke`${item.description}`,
      ke`<div>${getRelativeTime(item.finishTimestamp)}</div>
                <small>${item.finishTimestamp.toLocaleString()}</small>`,
      this.taskStatus(item),
      ke`<ak-action-button
                class="pf-m-plain"
                .apiRequest=${() => {
        return new EventsApi(DEFAULT_CONFIG).eventsSystemTasksRunCreate({
          uuid: item.uuid
        }).then(() => {
          this.dispatchEvent(
            new CustomEvent(EVENT_REFRESH, {
              bubbles: true,
              composed: true
            })
          );
        });
      }}
            >
                <pf-tooltip position="top" content=${msg("Restart task")}>
                    <i class="fas fa-redo" aria-hidden="true"></i>
                </pf-tooltip>
            </ak-action-button>`
    ];
  }
};
__decorateClass([
  n()
], SystemTaskListPage.prototype, "order", 2);
SystemTaskListPage = __decorateClass([
  t("ak-system-task-list")
], SystemTaskListPage);
export {
  SystemTaskListPage
};
//# sourceMappingURL=SystemTaskListPage-ZMEYV564.js.map
