import {
  PropertymappingsApi
} from "./chunk-H6O674E7.js";
import {
  FlowSearch_default
} from "./chunk-LEBYUIHG.js";
import {
  AkControlElement
} from "./chunk-O6PXCBWL.js";
import {
  ModelForm
} from "./chunk-AYF4HFW2.js";
import {
  spread
} from "./chunk-ENUGJATC.js";
import {
  ProvidersApi
} from "./chunk-VREDFYGR.js";
import {
  SourcesApi
} from "./chunk-CDWXKNE6.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-JUOHD3PM.js";
import {
  form_control_default,
  input_group_default
} from "./chunk-KZUPUEAQ.js";
import {
  to
} from "./chunk-KP2VLRW5.js";
import {
  ClientTypeEnum,
  DEFAULT_CONFIG,
  DigestAlgorithmEnum,
  IssuerModeEnum,
  MatchingModeEnum,
  SignatureAlgorithmEnum,
  SpBindingEnum,
  SubModeEnum,
  ascii_letters,
  digits,
  first,
  n,
  patternfly_base_default,
  r,
  r2,
  randomString,
  t
} from "./chunk-AMC4UCMS.js";
import {
  i,
  ke,
  msg
} from "./chunk-XFT4DB4U.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/providers/BaseProviderForm.ts
var BaseProviderForm = class extends ModelForm {
  getSuccessMessage() {
    return this.instance ? msg("Successfully updated provider.") : msg("Successfully created provider.");
  }
};

// src/admin/providers/oauth2/OAuth2ProviderRedirectURI.ts
var OAuth2ProviderRedirectURI = class extends AkControlElement {
  constructor() {
    super(...arguments);
    this.redirectURI = {
      matchingMode: MatchingModeEnum.Strict,
      url: ""
    };
  }
  static get styles() {
    return [
      patternfly_base_default,
      input_group_default,
      form_control_default,
      i`
                .pf-c-input-group select {
                    width: 10em;
                }
            `
    ];
  }
  json() {
    return Object.fromEntries(
      Array.from(this.controls ?? []).map((control) => [control.name, control.value])
    );
  }
  get isValid() {
    return true;
  }
  render() {
    const onChange = () => {
      this.dispatchEvent(new Event("change", { composed: true, bubbles: true }));
    };
    return ke`<div class="pf-c-input-group">
            <select
                name="matchingMode"
                class="pf-c-form-control ak-form-control"
                @change=${onChange}
            >
                <option
                    value="${MatchingModeEnum.Strict}"
                    ?selected=${this.redirectURI.matchingMode === MatchingModeEnum.Strict}
                >
                    ${msg("Strict")}
                </option>
                <option
                    value="${MatchingModeEnum.Regex}"
                    ?selected=${this.redirectURI.matchingMode === MatchingModeEnum.Regex}
                >
                    ${msg("Regex")}
                </option>
            </select>
            <input
                type="text"
                @change=${onChange}
                value="${to(this.redirectURI.url ?? void 0)}"
                class="pf-c-form-control ak-form-control"
                required
                id="url"
                placeholder=${msg("URL")}
                name="url"
                tabindex="1"
            />
        </div>`;
  }
};
__decorateClass([
  n({ type: Object, attribute: false })
], OAuth2ProviderRedirectURI.prototype, "redirectURI", 2);
__decorateClass([
  r2(".ak-form-control")
], OAuth2ProviderRedirectURI.prototype, "controls", 2);
OAuth2ProviderRedirectURI = __decorateClass([
  t("ak-provider-oauth2-redirect-uri")
], OAuth2ProviderRedirectURI);
function akOAuthRedirectURIInput(properties) {
  return ke`<ak-provider-oauth2-redirect-uri
        ${spread(properties)}
    ></ak-provider-oauth2-redirect-uri>`;
}

// src/admin/providers/oauth2/OAuth2PropertyMappings.ts
var defaultScopes = [
  "goauthentik.io/providers/oauth2/scope-openid",
  "goauthentik.io/providers/oauth2/scope-email",
  "goauthentik.io/providers/oauth2/scope-profile"
];
async function oauth2PropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderScopeList({
    ordering: "scope_name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((scope) => [scope.pk, scope.name, scope.name, scope])
  };
}
function makeOAuth2PropertyMappingsSelector(instanceMappings) {
  const localMappings = instanceMappings ? new Set(instanceMappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, scope]) => scope?.managed && defaultScopes.includes(scope?.managed);
}

// src/admin/providers/oauth2/OAuth2Sources.ts
async function oauth2SourcesProvider(page = 1, search = "") {
  const oauthSources = await new SourcesApi(DEFAULT_CONFIG).sourcesOauthList({
    ordering: "name",
    hasJwks: true,
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: oauthSources.pagination,
    options: oauthSources.results.map((source) => [
      source.pk,
      `${source.name} (${source.slug})`
    ])
  };
}
function makeSourceSelector(instanceSources) {
  const localSources = instanceSources ? new Set(instanceSources) : void 0;
  return localSources ? ([pk, _]) => localSources.has(pk) : ([_0, _1, _2, prompt]) => prompt !== void 0;
}

// src/admin/providers/oauth2/OAuth2ProviderForm.ts
var clientTypeOptions = [
  {
    label: msg("Confidential"),
    value: ClientTypeEnum.Confidential,
    default: true,
    description: ke`${msg(
      "Confidential clients are capable of maintaining the confidentiality of their credentials such as client secrets"
    )}`
  },
  {
    label: msg("Public"),
    value: ClientTypeEnum.Public,
    description: ke`${msg(
      "Public clients are incapable of maintaining the confidentiality and should use methods like PKCE. "
    )}`
  }
];
var subjectModeOptions = [
  {
    label: msg("Based on the User's hashed ID"),
    value: SubModeEnum.HashedUserId,
    default: true
  },
  {
    label: msg("Based on the User's ID"),
    value: SubModeEnum.UserId
  },
  {
    label: msg("Based on the User's UUID"),
    value: SubModeEnum.UserUuid
  },
  {
    label: msg("Based on the User's username"),
    value: SubModeEnum.UserUsername
  },
  {
    label: msg("Based on the User's Email"),
    value: SubModeEnum.UserEmail,
    description: ke`${msg("This is recommended over the UPN mode.")}`
  },
  {
    label: msg("Based on the User's UPN"),
    value: SubModeEnum.UserUpn,
    description: ke`${msg(
      "Requires the user to have a 'upn' attribute set, and falls back to hashed user ID. Use this mode only if you have different UPN and Mail domains."
    )}`
  }
];
var issuerModeOptions = [
  {
    label: msg("Each provider has a different issuer, based on the application slug"),
    value: IssuerModeEnum.PerProvider,
    default: true
  },
  {
    label: msg("Same identifier is used for all providers"),
    value: IssuerModeEnum.Global
  }
];
var redirectUriHelpMessages = [
  msg(
    "Valid redirect URIs after a successful authorization flow. Also specify any origins here for Implicit flows."
  ),
  msg(
    "If no explicit redirect URIs are specified, the first successfully used redirect URI will be saved."
  ),
  msg(
    'To allow any redirect URI, set the mode to Regex and the value to ".*". Be aware of the possible security implications this can have.'
  )
];
var redirectUriHelp = ke`${redirectUriHelpMessages.map(
  (m) => ke`<p class="pf-c-form__helper-text">${m}</p>`
)}`;
var OAuth2ProviderFormPage = class extends BaseProviderForm {
  constructor() {
    super(...arguments);
    this.showClientSecret = true;
    this.redirectUris = [];
  }
  static get styles() {
    return super.styles.concat(i`
            ak-array-input {
                width: 100%;
            }
        `);
  }
  async loadInstance(pk) {
    const provider = await new ProvidersApi(DEFAULT_CONFIG).providersOauth2Retrieve({
      id: pk
    });
    this.showClientSecret = provider.clientType === ClientTypeEnum.Confidential;
    this.redirectUris = provider.redirectUris;
    return provider;
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersOauth2Update({
        id: this.instance.pk,
        oAuth2ProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersOauth2Create({
        oAuth2ProviderRequest: data
      });
    }
  }
  renderForm() {
    const provider = this.instance;
    return ke` <ak-text-input
                name="name"
                label=${msg("Name")}
                value=${to(provider?.name)}
                required
            ></ak-text-input>

            <ak-form-element-horizontal
                name="authenticationFlow"
                label=${msg("Authentication flow")}
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${provider?.authenticationFlow}
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when a user access this provider and is not authenticated.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                name="authorizationFlow"
                label=${msg("Authorization flow")}
                required
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${provider?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-radio-input
                        name="clientType"
                        label=${msg("Client type")}
                        .value=${provider?.clientType}
                        required
                        @change=${(ev) => {
      this.showClientSecret = ev.detail.value !== ClientTypeEnum.Public;
    }}
                        .options=${clientTypeOptions}
                    >
                    </ak-radio-input>
                    <ak-text-input
                        name="clientId"
                        label=${msg("Client ID")}
                        value="${first(
      provider?.clientId,
      randomString(40, ascii_letters + digits)
    )}"
                        required
                    >
                    </ak-text-input>
                    <ak-text-input
                        name="clientSecret"
                        label=${msg("Client Secret")}
                        value="${first(
      provider?.clientSecret,
      randomString(128, ascii_letters + digits)
    )}"
                        ?hidden=${!this.showClientSecret}
                    >
                    </ak-text-input>
                    <ak-form-element-horizontal
                        label=${msg("Redirect URIs/Origins")}
                        required
                        name="redirectUris"
                    >
                        <ak-array-input
                            .items=${this.instance?.redirectUris ?? []}
                            .newItem=${() => ({ matchingMode: MatchingModeEnum.Strict, url: "" })}
                            .row=${(f) => akOAuthRedirectURIInput({
      ".redirectURI": f,
      "style": "width: 100%",
      "name": "oauth2-redirect-uri"
    })}
                        >
                        </ak-array-input>
                        ${redirectUriHelp}
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal label=${msg("Signing Key")} name="signingKey">
                        <!-- NOTE: 'null' cast to 'undefined' on signingKey to satisfy Lit requirements -->
                        <ak-crypto-certificate-search
                            certificate=${to(this.instance?.signingKey ?? void 0)}
                            singleton
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">${msg("Key used to sign the tokens.")}</p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>

            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-text-input
                        name="accessCodeValidity"
                        label=${msg("Access code validity")}
                        required
                        value="${first(provider?.accessCodeValidity, "minutes=1")}"
                        .bighelp=${ke`<p class="pf-c-form__helper-text">
                                ${msg("Configure how long access codes are valid for.")}
                            </p>
                            <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                    >
                    </ak-text-input>
                    <ak-text-input
                        name="accessTokenValidity"
                        label=${msg("Access Token validity")}
                        value="${first(provider?.accessTokenValidity, "minutes=5")}"
                        required
                        .bighelp=${ke` <p class="pf-c-form__helper-text">
                                ${msg("Configure how long access tokens are valid for.")}
                            </p>
                            <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                    >
                    </ak-text-input>

                    <ak-text-input
                        name="refreshTokenValidity"
                        label=${msg("Refresh Token validity")}
                        value="${first(provider?.refreshTokenValidity, "days=30")}"
                        ?required=${true}
                        .bighelp=${ke` <p class="pf-c-form__helper-text">
                                ${msg("Configure how long refresh tokens are valid for.")}
                            </p>
                            <ak-utils-time-delta-help></ak-utils-time-delta-help>`}
                    >
                    </ak-text-input>
                    <ak-form-element-horizontal label=${msg("Scopes")} name="propertyMappings">
                        <ak-dual-select-dynamic-selected
                            .provider=${oauth2PropertyMappingsProvider}
                            .selector=${makeOAuth2PropertyMappingsSelector(
      provider?.propertyMappings
    )}
                            available-label=${msg("Available Scopes")}
                            selected-label=${msg("Selected Scopes")}
                        ></ak-dual-select-dynamic-selected>

                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Select which scopes can be used by the client. The client still has to specify the scope to access the data."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-radio-input
                        name="subMode"
                        label=${msg("Subject mode")}
                        required
                        .options=${subjectModeOptions}
                        .value=${provider?.subMode}
                        help=${msg(
      "Configure what data should be used as unique User Identifier. For most cases, the default should be fine."
    )}
                    >
                    </ak-radio-input>
                    <ak-switch-input
                        name="includeClaimsInIdToken"
                        label=${msg("Include claims in id_token")}
                        ?checked=${first(provider?.includeClaimsInIdToken, true)}
                        help=${msg(
      "Include User claims from scopes in the id_token, for applications that don't access the userinfo endpoint."
    )}
                    ></ak-switch-input>
                    <ak-radio-input
                        name="issuerMode"
                        label=${msg("Issuer mode")}
                        required
                        .options=${issuerModeOptions}
                        .value=${provider?.issuerMode}
                        help=${msg(
      "Configure how the issuer field of the ID Token should be filled."
    )}
                    >
                    </ak-radio-input>
                </div>
            </ak-form-group>

            <ak-form-group>
                <span slot="header">${msg("Machine-to-Machine authentication settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Trusted OIDC Sources")}
                        name="jwksSources"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${oauth2SourcesProvider}
                            .selector=${makeSourceSelector(provider?.jwksSources)}
                            available-label=${msg("Available Sources")}
                            selected-label=${msg("Selected Sources")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "JWTs signed by certificates configured in the selected sources can be used to authenticate to this provider."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], OAuth2ProviderFormPage.prototype, "showClientSecret", 2);
__decorateClass([
  r()
], OAuth2ProviderFormPage.prototype, "redirectUris", 2);
OAuth2ProviderFormPage = __decorateClass([
  t("ak-provider-oauth2-form")
], OAuth2ProviderFormPage);

// src/admin/common/ak-flow-search/ak-branded-flow-search.ts
var AkBrandedFlowSearch = class extends FlowSearch_default {
  constructor() {
    super();
    this.selected = this.selected.bind(this);
  }
  selected(flow) {
    return super.selected(flow) || flow.pk === this.brandFlow;
  }
};
__decorateClass([
  n({ attribute: false, type: String })
], AkBrandedFlowSearch.prototype, "brandFlow", 2);
AkBrandedFlowSearch = __decorateClass([
  t("ak-branded-flow-search")
], AkBrandedFlowSearch);

// src/admin/providers/proxy/ProxyProviderPropertyMappings.ts
async function proxyPropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderScopeList({
    ordering: "scope_name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((scope) => [scope.pk, scope.name, scope.name, scope])
  };
}
function makeProxyPropertyMappingsSelector(mappings) {
  const localMappings = mappings ? new Set(mappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, scope]) => !(scope?.managed ?? "").startsWith("goauthentik.io/providers");
}

// src/admin/providers/rac/RACPropertyMappings.ts
async function racPropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderRacList({
    ordering: "name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((mapping) => [mapping.pk, mapping.name])
  };
}
function makeRACPropertyMappingsSelector(instanceMappings) {
  const localMappings = new Set(instanceMappings ?? []);
  return ([pk, _]) => localMappings.has(pk);
}

// src/admin/applications/wizard/methods/saml/SamlProviderOptions.ts
function toOptions(options) {
  return options.map(([label, value, isDefault]) => ({
    label,
    value,
    default: isDefault ?? false
  }));
}
var spBindingOptions = toOptions([
  [msg("Redirect"), SpBindingEnum.Redirect, true],
  [msg("Post"), SpBindingEnum.Post]
]);
var digestAlgorithmOptions = toOptions([
  ["SHA1", DigestAlgorithmEnum._200009Xmldsigsha1],
  ["SHA256", DigestAlgorithmEnum._200104Xmlencsha256, true],
  ["SHA384", DigestAlgorithmEnum._200104XmldsigMoresha384],
  ["SHA512", DigestAlgorithmEnum._200104Xmlencsha512]
]);
var signatureAlgorithmOptions = toOptions([
  ["RSA-SHA1", SignatureAlgorithmEnum._200009XmldsigrsaSha1],
  ["RSA-SHA256", SignatureAlgorithmEnum._200104XmldsigMorersaSha256, true],
  ["RSA-SHA384", SignatureAlgorithmEnum._200104XmldsigMorersaSha384],
  ["RSA-SHA512", SignatureAlgorithmEnum._200104XmldsigMorersaSha512],
  ["ECDSA-SHA1", SignatureAlgorithmEnum._200104XmldsigMoreecdsaSha1],
  ["ECDSA-SHA256", SignatureAlgorithmEnum._200104XmldsigMoreecdsaSha256],
  ["ECDSA-SHA384", SignatureAlgorithmEnum._200104XmldsigMoreecdsaSha384],
  ["ECDSA-SHA512", SignatureAlgorithmEnum._200104XmldsigMoreecdsaSha512],
  ["DSA-SHA1", SignatureAlgorithmEnum._200009XmldsigdsaSha1]
]);

export {
  oauth2PropertyMappingsProvider,
  makeOAuth2PropertyMappingsSelector,
  BaseProviderForm,
  akOAuthRedirectURIInput,
  oauth2SourcesProvider,
  makeSourceSelector,
  clientTypeOptions,
  subjectModeOptions,
  issuerModeOptions,
  redirectUriHelp,
  proxyPropertyMappingsProvider,
  makeProxyPropertyMappingsSelector,
  racPropertyMappingsProvider,
  makeRACPropertyMappingsSelector,
  spBindingOptions,
  digestAlgorithmOptions,
  signatureAlgorithmOptions
};
//# sourceMappingURL=chunk-TE2OYAEB.js.map
