import {
  BaseProviderForm,
  digestAlgorithmOptions,
  makeProxyPropertyMappingsSelector,
  makeRACPropertyMappingsSelector,
  makeSourceSelector,
  oauth2SourcesProvider,
  proxyPropertyMappingsProvider,
  racPropertyMappingsProvider,
  signatureAlgorithmOptions
} from "./chunk-TE2OYAEB.js";
import {
  PropertymappingsApi
} from "./chunk-H6O674E7.js";
import {
  FlowSearch,
  getFlowValue,
  renderDescription,
  renderElement
} from "./chunk-LEBYUIHG.js";
import {
  browser_default
} from "./chunk-OBKOQLSR.js";
import {
  ModelForm
} from "./chunk-AYF4HFW2.js";
import {
  ProvidersApi
} from "./chunk-VREDFYGR.js";
import {
  FlowsInstancesListDesignationEnum
} from "./chunk-JUOHD3PM.js";
import {
  list_default
} from "./chunk-F4SCNWUD.js";
import {
  to
} from "./chunk-KP2VLRW5.js";
import {
  CoreApi,
  DEFAULT_CONFIG,
  LDAPAPIAccessMode,
  OutgoingSyncDeleteAction,
  ProxyMode,
  SpBindingEnum,
  WithBrandConfig,
  ascii_letters,
  content_default,
  digits,
  first,
  r,
  randomString,
  t
} from "./chunk-AMC4UCMS.js";
import {
  D,
  ke,
  msg
} from "./chunk-XFT4DB4U.js";
import {
  __decorateClass
} from "./chunk-KZ3QJOBN.js";

// src/admin/providers/ldap/LDAPProviderForm.ts
var LDAPProviderFormPage = class extends WithBrandConfig(BaseProviderForm) {
  async loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersLdapRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersLdapUpdate({
        id: this.instance.pk,
        lDAPProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersLdapCreate({
        lDAPProviderRequest: data
      });
    }
  }
  // All Provider objects have an Authorization flow, but not all providers have an Authentication
  // flow. LDAP needs only one field, but it is not an Authorization field, it is an
  // Authentication field. So, yeah, we're using the authorization field to store the
  // authentication information, which is why the ak-branded-flow-search call down there looks so
  // weird-- we're looking up Authentication flows, but we're storing them in the Authorization
  // field of the target Provider.
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Bind flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-branded-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authorizationFlow}
                    .brandFlow=${this.brand?.flowAuthentication}
                    required
                ></ak-branded-flow-search>
                <p class="pf-c-form__helper-text">${msg("Flow used for users to authenticate.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Bind mode")} name="bindMode">
                <ak-radio
                    .options=${[
      {
        label: msg("Cached binding"),
        value: LDAPAPIAccessMode.Cached,
        default: true,
        description: ke`${msg(
          "Flow is executed and session is cached in memory. Flow is executed when session expires"
        )}`
      },
      {
        label: msg("Direct binding"),
        value: LDAPAPIAccessMode.Direct,
        description: ke`${msg(
          "Always execute the configured bind flow to authenticate the user"
        )}`
      }
    ]}
                    .value=${this.instance?.bindMode}
                >
                </ak-radio>
                <p class="pf-c-form__helper-text">
                    ${msg("Configure how the outpost authenticates requests.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal label=${msg("Search mode")} name="searchMode">
                <ak-radio
                    .options=${[
      {
        label: msg("Cached querying"),
        value: LDAPAPIAccessMode.Cached,
        default: true,
        description: ke`${msg(
          "The outpost holds all users and groups in-memory and will refresh every 5 Minutes"
        )}`
      },
      {
        label: msg("Direct querying"),
        value: LDAPAPIAccessMode.Direct,
        description: ke`${msg(
          "Always returns the latest data, but slower than cached querying"
        )}`
      }
    ]}
                    .value=${this.instance?.searchMode}
                >
                </ak-radio>
                <p class="pf-c-form__helper-text">
                    ${msg("Configure how the outpost queries the core authentik server's users.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="mfaSupport">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.mfaSupport, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Code-based MFA Support")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon."
    )}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Base DN")}
                        ?required=${true}
                        name="baseDn"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.baseDn, "DC=ldap,DC=goauthentik,DC=io")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "LDAP DN under which bind requests and search requests can be made."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Certificate")} name="certificate">
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.certificate}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The certificate for the above configured Base DN. As a fallback, the provider uses a self-signed certificate."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("TLS Server name")}
                        name="tlsServerName"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.tlsServerName, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "DNS name for which the above configured certificate should be used. The certificate cannot be detected based on the base DN, as the SSL/TLS negotiation happens before such data is exchanged."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("UID start number")}
                        ?required=${true}
                        name="uidStartNumber"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.uidStartNumber, 2e3)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The start for uidNumbers, this number is added to the user.Pk to make sure that the numbers aren't too low for POSIX users. Default is 2000 to ensure that we don't collide with local users uidNumber"
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("GID start number")}
                        ?required=${true}
                        name="gidStartNumber"
                    >
                        <input
                            type="number"
                            value="${first(this.instance?.gidStartNumber, 4e3)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "The start for gidNumbers, this number is added to a number generated from the group.Pk to make sure that the numbers aren't too low for POSIX groups. Default is 4000 to ensure that we don't collide with local groups or users primary groups gidNumber"
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
LDAPProviderFormPage = __decorateClass([
  t("ak-provider-ldap-form")
], LDAPProviderFormPage);

// node_modules/@patternfly/patternfly/utilities/Spacing/spacing.css
var spacing_default = ".pf-u-m-auto {\n  margin: auto !important;\n}\n\n.pf-u-m-0 {\n  margin: 0 !important;\n}\n\n.pf-u-m-xs {\n  margin: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-m-sm {\n  margin: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-m-md {\n  margin: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-m-lg {\n  margin: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-m-xl {\n  margin: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-m-2xl {\n  margin: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-m-3xl {\n  margin: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-m-4xl {\n  margin: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mt-auto {\n  margin-top: auto !important;\n}\n\n.pf-u-mt-0 {\n  margin-top: 0 !important;\n}\n\n.pf-u-mt-xs {\n  margin-top: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mt-sm {\n  margin-top: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mt-md {\n  margin-top: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mt-lg {\n  margin-top: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mt-xl {\n  margin-top: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mt-2xl {\n  margin-top: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mt-3xl {\n  margin-top: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mt-4xl {\n  margin-top: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mr-auto {\n  margin-right: auto !important;\n}\n\n.pf-u-mr-0 {\n  margin-right: 0 !important;\n}\n\n.pf-u-mr-xs {\n  margin-right: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mr-sm {\n  margin-right: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mr-md {\n  margin-right: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mr-lg {\n  margin-right: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mr-xl {\n  margin-right: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mr-2xl {\n  margin-right: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mr-3xl {\n  margin-right: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mr-4xl {\n  margin-right: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mb-auto {\n  margin-bottom: auto !important;\n}\n\n.pf-u-mb-0 {\n  margin-bottom: 0 !important;\n}\n\n.pf-u-mb-xs {\n  margin-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mb-sm {\n  margin-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mb-md {\n  margin-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mb-lg {\n  margin-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mb-xl {\n  margin-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mb-2xl {\n  margin-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mb-3xl {\n  margin-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mb-4xl {\n  margin-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-ml-auto {\n  margin-left: auto !important;\n}\n\n.pf-u-ml-0 {\n  margin-left: 0 !important;\n}\n\n.pf-u-ml-xs {\n  margin-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-ml-sm {\n  margin-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-ml-md {\n  margin-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-ml-lg {\n  margin-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-ml-xl {\n  margin-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-ml-2xl {\n  margin-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-ml-3xl {\n  margin-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-ml-4xl {\n  margin-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-mx-auto {\n  margin-right: auto !important;\n  margin-left: auto !important;\n}\n\n.pf-u-mx-0 {\n  margin-right: 0 !important;\n  margin-left: 0 !important;\n}\n\n.pf-u-mx-xs {\n  margin-right: var(--pf-global--spacer--xs) !important;\n  margin-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-mx-sm {\n  margin-right: var(--pf-global--spacer--sm) !important;\n  margin-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-mx-md {\n  margin-right: var(--pf-global--spacer--md) !important;\n  margin-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-mx-lg {\n  margin-right: var(--pf-global--spacer--lg) !important;\n  margin-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-mx-xl {\n  margin-right: var(--pf-global--spacer--xl) !important;\n  margin-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-mx-2xl {\n  margin-right: var(--pf-global--spacer--2xl) !important;\n  margin-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-mx-3xl {\n  margin-right: var(--pf-global--spacer--3xl) !important;\n  margin-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-mx-4xl {\n  margin-right: var(--pf-global--spacer--4xl) !important;\n  margin-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-my-auto {\n  margin-top: auto !important;\n  margin-bottom: auto !important;\n}\n\n.pf-u-my-0 {\n  margin-top: 0 !important;\n  margin-bottom: 0 !important;\n}\n\n.pf-u-my-xs {\n  margin-top: var(--pf-global--spacer--xs) !important;\n  margin-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-my-sm {\n  margin-top: var(--pf-global--spacer--sm) !important;\n  margin-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-my-md {\n  margin-top: var(--pf-global--spacer--md) !important;\n  margin-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-my-lg {\n  margin-top: var(--pf-global--spacer--lg) !important;\n  margin-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-my-xl {\n  margin-top: var(--pf-global--spacer--xl) !important;\n  margin-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-my-2xl {\n  margin-top: var(--pf-global--spacer--2xl) !important;\n  margin-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-my-3xl {\n  margin-top: var(--pf-global--spacer--3xl) !important;\n  margin-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-my-4xl {\n  margin-top: var(--pf-global--spacer--4xl) !important;\n  margin-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-p-auto {\n  padding: auto !important;\n}\n\n.pf-u-p-0 {\n  padding: 0 !important;\n}\n\n.pf-u-p-xs {\n  padding: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-p-sm {\n  padding: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-p-md {\n  padding: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-p-lg {\n  padding: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-p-xl {\n  padding: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-p-2xl {\n  padding: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-p-3xl {\n  padding: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-p-4xl {\n  padding: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pt-auto {\n  padding-top: auto !important;\n}\n\n.pf-u-pt-0 {\n  padding-top: 0 !important;\n}\n\n.pf-u-pt-xs {\n  padding-top: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pt-sm {\n  padding-top: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pt-md {\n  padding-top: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pt-lg {\n  padding-top: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pt-xl {\n  padding-top: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pt-2xl {\n  padding-top: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pt-3xl {\n  padding-top: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pt-4xl {\n  padding-top: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pr-auto {\n  padding-right: auto !important;\n}\n\n.pf-u-pr-0 {\n  padding-right: 0 !important;\n}\n\n.pf-u-pr-xs {\n  padding-right: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pr-sm {\n  padding-right: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pr-md {\n  padding-right: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pr-lg {\n  padding-right: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pr-xl {\n  padding-right: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pr-2xl {\n  padding-right: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pr-3xl {\n  padding-right: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pr-4xl {\n  padding-right: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pb-auto {\n  padding-bottom: auto !important;\n}\n\n.pf-u-pb-0 {\n  padding-bottom: 0 !important;\n}\n\n.pf-u-pb-xs {\n  padding-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pb-sm {\n  padding-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pb-md {\n  padding-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pb-lg {\n  padding-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pb-xl {\n  padding-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pb-2xl {\n  padding-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pb-3xl {\n  padding-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pb-4xl {\n  padding-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-pl-auto {\n  padding-left: auto !important;\n}\n\n.pf-u-pl-0 {\n  padding-left: 0 !important;\n}\n\n.pf-u-pl-xs {\n  padding-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-pl-sm {\n  padding-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-pl-md {\n  padding-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-pl-lg {\n  padding-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-pl-xl {\n  padding-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-pl-2xl {\n  padding-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-pl-3xl {\n  padding-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-pl-4xl {\n  padding-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-px-auto {\n  padding-right: auto !important;\n  padding-left: auto !important;\n}\n\n.pf-u-px-0 {\n  padding-right: 0 !important;\n  padding-left: 0 !important;\n}\n\n.pf-u-px-xs {\n  padding-right: var(--pf-global--spacer--xs) !important;\n  padding-left: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-px-sm {\n  padding-right: var(--pf-global--spacer--sm) !important;\n  padding-left: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-px-md {\n  padding-right: var(--pf-global--spacer--md) !important;\n  padding-left: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-px-lg {\n  padding-right: var(--pf-global--spacer--lg) !important;\n  padding-left: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-px-xl {\n  padding-right: var(--pf-global--spacer--xl) !important;\n  padding-left: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-px-2xl {\n  padding-right: var(--pf-global--spacer--2xl) !important;\n  padding-left: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-px-3xl {\n  padding-right: var(--pf-global--spacer--3xl) !important;\n  padding-left: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-px-4xl {\n  padding-right: var(--pf-global--spacer--4xl) !important;\n  padding-left: var(--pf-global--spacer--4xl) !important;\n}\n\n.pf-u-py-auto {\n  padding-top: auto !important;\n  padding-bottom: auto !important;\n}\n\n.pf-u-py-0 {\n  padding-top: 0 !important;\n  padding-bottom: 0 !important;\n}\n\n.pf-u-py-xs {\n  padding-top: var(--pf-global--spacer--xs) !important;\n  padding-bottom: var(--pf-global--spacer--xs) !important;\n}\n\n.pf-u-py-sm {\n  padding-top: var(--pf-global--spacer--sm) !important;\n  padding-bottom: var(--pf-global--spacer--sm) !important;\n}\n\n.pf-u-py-md {\n  padding-top: var(--pf-global--spacer--md) !important;\n  padding-bottom: var(--pf-global--spacer--md) !important;\n}\n\n.pf-u-py-lg {\n  padding-top: var(--pf-global--spacer--lg) !important;\n  padding-bottom: var(--pf-global--spacer--lg) !important;\n}\n\n.pf-u-py-xl {\n  padding-top: var(--pf-global--spacer--xl) !important;\n  padding-bottom: var(--pf-global--spacer--xl) !important;\n}\n\n.pf-u-py-2xl {\n  padding-top: var(--pf-global--spacer--2xl) !important;\n  padding-bottom: var(--pf-global--spacer--2xl) !important;\n}\n\n.pf-u-py-3xl {\n  padding-top: var(--pf-global--spacer--3xl) !important;\n  padding-bottom: var(--pf-global--spacer--3xl) !important;\n}\n\n.pf-u-py-4xl {\n  padding-top: var(--pf-global--spacer--4xl) !important;\n  padding-bottom: var(--pf-global--spacer--4xl) !important;\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-auto-on-sm {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-0-on-sm {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-xs-on-sm {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-sm-on-sm {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-md-on-sm {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-lg-on-sm {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-xl-on-sm {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-2xl-on-sm {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-3xl-on-sm {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-m-4xl-on-sm {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-auto-on-sm {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-0-on-sm {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-xs-on-sm {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-sm-on-sm {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-md-on-sm {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-lg-on-sm {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-xl-on-sm {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-2xl-on-sm {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-3xl-on-sm {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mt-4xl-on-sm {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-auto-on-sm {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-0-on-sm {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-xs-on-sm {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-sm-on-sm {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-md-on-sm {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-lg-on-sm {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-xl-on-sm {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-2xl-on-sm {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-3xl-on-sm {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mr-4xl-on-sm {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-auto-on-sm {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-0-on-sm {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-xs-on-sm {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-sm-on-sm {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-md-on-sm {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-lg-on-sm {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-2xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-3xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mb-4xl-on-sm {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-auto-on-sm {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-0-on-sm {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-xs-on-sm {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-sm-on-sm {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-md-on-sm {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-lg-on-sm {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-xl-on-sm {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-2xl-on-sm {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-3xl-on-sm {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-ml-4xl-on-sm {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-auto-on-sm {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-0-on-sm {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-xs-on-sm {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-sm-on-sm {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-md-on-sm {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-lg-on-sm {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-xl-on-sm {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-2xl-on-sm {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-3xl-on-sm {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-mx-4xl-on-sm {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-auto-on-sm {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-0-on-sm {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-xs-on-sm {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-sm-on-sm {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-md-on-sm {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-lg-on-sm {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-xl-on-sm {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-2xl-on-sm {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-3xl-on-sm {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-my-4xl-on-sm {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-auto-on-sm {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-0-on-sm {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-xs-on-sm {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-sm-on-sm {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-md-on-sm {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-lg-on-sm {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-xl-on-sm {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-2xl-on-sm {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-3xl-on-sm {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-p-4xl-on-sm {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-auto-on-sm {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-0-on-sm {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-xs-on-sm {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-sm-on-sm {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-md-on-sm {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-lg-on-sm {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-xl-on-sm {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-2xl-on-sm {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-3xl-on-sm {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pt-4xl-on-sm {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-auto-on-sm {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-0-on-sm {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-xs-on-sm {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-sm-on-sm {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-md-on-sm {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-lg-on-sm {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-xl-on-sm {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-2xl-on-sm {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-3xl-on-sm {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pr-4xl-on-sm {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-auto-on-sm {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-0-on-sm {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-xs-on-sm {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-sm-on-sm {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-md-on-sm {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-lg-on-sm {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-2xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-3xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pb-4xl-on-sm {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-auto-on-sm {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-0-on-sm {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-xs-on-sm {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-sm-on-sm {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-md-on-sm {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-lg-on-sm {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-xl-on-sm {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-2xl-on-sm {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-3xl-on-sm {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-pl-4xl-on-sm {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-auto-on-sm {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-0-on-sm {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-xs-on-sm {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-sm-on-sm {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-md-on-sm {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-lg-on-sm {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-xl-on-sm {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-2xl-on-sm {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-3xl-on-sm {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-px-4xl-on-sm {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-auto-on-sm {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-0-on-sm {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-xs-on-sm {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-sm-on-sm {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-md-on-sm {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-lg-on-sm {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-xl-on-sm {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-2xl-on-sm {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-3xl-on-sm {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 576px) {\n  .pf-u-py-4xl-on-sm {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-auto-on-md {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-0-on-md {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-xs-on-md {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-sm-on-md {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-md-on-md {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-lg-on-md {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-xl-on-md {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-2xl-on-md {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-3xl-on-md {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-m-4xl-on-md {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-auto-on-md {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-0-on-md {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-xs-on-md {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-sm-on-md {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-md-on-md {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-lg-on-md {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-xl-on-md {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-2xl-on-md {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-3xl-on-md {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mt-4xl-on-md {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-auto-on-md {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-0-on-md {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-xs-on-md {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-sm-on-md {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-md-on-md {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-lg-on-md {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-xl-on-md {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-2xl-on-md {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-3xl-on-md {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mr-4xl-on-md {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-auto-on-md {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-0-on-md {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-xs-on-md {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-sm-on-md {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-md-on-md {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-lg-on-md {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-xl-on-md {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-2xl-on-md {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-3xl-on-md {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mb-4xl-on-md {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-auto-on-md {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-0-on-md {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-xs-on-md {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-sm-on-md {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-md-on-md {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-lg-on-md {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-xl-on-md {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-2xl-on-md {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-3xl-on-md {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-ml-4xl-on-md {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-auto-on-md {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-0-on-md {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-xs-on-md {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-sm-on-md {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-md-on-md {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-lg-on-md {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-xl-on-md {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-2xl-on-md {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-3xl-on-md {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-mx-4xl-on-md {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-auto-on-md {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-0-on-md {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-xs-on-md {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-sm-on-md {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-md-on-md {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-lg-on-md {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-xl-on-md {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-2xl-on-md {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-3xl-on-md {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-my-4xl-on-md {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-auto-on-md {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-0-on-md {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-xs-on-md {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-sm-on-md {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-md-on-md {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-lg-on-md {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-xl-on-md {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-2xl-on-md {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-3xl-on-md {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-p-4xl-on-md {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-auto-on-md {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-0-on-md {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-xs-on-md {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-sm-on-md {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-md-on-md {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-lg-on-md {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-xl-on-md {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-2xl-on-md {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-3xl-on-md {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pt-4xl-on-md {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-auto-on-md {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-0-on-md {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-xs-on-md {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-sm-on-md {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-md-on-md {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-lg-on-md {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-xl-on-md {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-2xl-on-md {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-3xl-on-md {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pr-4xl-on-md {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-auto-on-md {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-0-on-md {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-xs-on-md {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-sm-on-md {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-md-on-md {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-lg-on-md {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-xl-on-md {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-2xl-on-md {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-3xl-on-md {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pb-4xl-on-md {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-auto-on-md {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-0-on-md {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-xs-on-md {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-sm-on-md {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-md-on-md {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-lg-on-md {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-xl-on-md {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-2xl-on-md {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-3xl-on-md {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-pl-4xl-on-md {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-auto-on-md {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-0-on-md {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-xs-on-md {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-sm-on-md {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-md-on-md {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-lg-on-md {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-xl-on-md {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-2xl-on-md {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-3xl-on-md {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-px-4xl-on-md {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-auto-on-md {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-0-on-md {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-xs-on-md {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-sm-on-md {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-md-on-md {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-lg-on-md {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-xl-on-md {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-2xl-on-md {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-3xl-on-md {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 768px) {\n  .pf-u-py-4xl-on-md {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-auto-on-lg {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-0-on-lg {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-xs-on-lg {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-sm-on-lg {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-md-on-lg {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-lg-on-lg {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-xl-on-lg {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-2xl-on-lg {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-3xl-on-lg {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-m-4xl-on-lg {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-auto-on-lg {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-0-on-lg {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-xs-on-lg {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-sm-on-lg {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-md-on-lg {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-lg-on-lg {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-xl-on-lg {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-2xl-on-lg {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-3xl-on-lg {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mt-4xl-on-lg {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-auto-on-lg {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-0-on-lg {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-xs-on-lg {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-sm-on-lg {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-md-on-lg {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-lg-on-lg {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-xl-on-lg {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-2xl-on-lg {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-3xl-on-lg {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mr-4xl-on-lg {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-auto-on-lg {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-0-on-lg {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-xs-on-lg {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-sm-on-lg {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-md-on-lg {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-lg-on-lg {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-2xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-3xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mb-4xl-on-lg {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-auto-on-lg {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-0-on-lg {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-xs-on-lg {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-sm-on-lg {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-md-on-lg {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-lg-on-lg {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-xl-on-lg {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-2xl-on-lg {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-3xl-on-lg {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-ml-4xl-on-lg {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-auto-on-lg {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-0-on-lg {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-xs-on-lg {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-sm-on-lg {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-md-on-lg {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-lg-on-lg {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-xl-on-lg {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-2xl-on-lg {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-3xl-on-lg {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-mx-4xl-on-lg {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-auto-on-lg {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-0-on-lg {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-xs-on-lg {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-sm-on-lg {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-md-on-lg {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-lg-on-lg {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-xl-on-lg {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-2xl-on-lg {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-3xl-on-lg {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-my-4xl-on-lg {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-auto-on-lg {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-0-on-lg {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-xs-on-lg {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-sm-on-lg {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-md-on-lg {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-lg-on-lg {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-xl-on-lg {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-2xl-on-lg {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-3xl-on-lg {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-p-4xl-on-lg {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-auto-on-lg {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-0-on-lg {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-xs-on-lg {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-sm-on-lg {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-md-on-lg {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-lg-on-lg {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-xl-on-lg {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-2xl-on-lg {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-3xl-on-lg {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pt-4xl-on-lg {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-auto-on-lg {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-0-on-lg {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-xs-on-lg {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-sm-on-lg {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-md-on-lg {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-lg-on-lg {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-xl-on-lg {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-2xl-on-lg {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-3xl-on-lg {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pr-4xl-on-lg {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-auto-on-lg {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-0-on-lg {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-xs-on-lg {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-sm-on-lg {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-md-on-lg {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-lg-on-lg {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-2xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-3xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pb-4xl-on-lg {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-auto-on-lg {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-0-on-lg {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-xs-on-lg {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-sm-on-lg {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-md-on-lg {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-lg-on-lg {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-xl-on-lg {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-2xl-on-lg {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-3xl-on-lg {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-pl-4xl-on-lg {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-auto-on-lg {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-0-on-lg {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-xs-on-lg {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-sm-on-lg {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-md-on-lg {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-lg-on-lg {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-xl-on-lg {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-2xl-on-lg {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-3xl-on-lg {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-px-4xl-on-lg {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-auto-on-lg {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-0-on-lg {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-xs-on-lg {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-sm-on-lg {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-md-on-lg {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-lg-on-lg {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-xl-on-lg {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-2xl-on-lg {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-3xl-on-lg {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 992px) {\n  .pf-u-py-4xl-on-lg {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-auto-on-xl {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-0-on-xl {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-xs-on-xl {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-sm-on-xl {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-md-on-xl {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-lg-on-xl {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-xl-on-xl {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-2xl-on-xl {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-3xl-on-xl {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-m-4xl-on-xl {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-auto-on-xl {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-0-on-xl {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-xs-on-xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-sm-on-xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-md-on-xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-lg-on-xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-xl-on-xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-2xl-on-xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-3xl-on-xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mt-4xl-on-xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-auto-on-xl {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-0-on-xl {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-xs-on-xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-sm-on-xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-md-on-xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-lg-on-xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-xl-on-xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-2xl-on-xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-3xl-on-xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mr-4xl-on-xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-auto-on-xl {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-0-on-xl {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-xs-on-xl {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-sm-on-xl {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-md-on-xl {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-lg-on-xl {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-2xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-3xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mb-4xl-on-xl {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-auto-on-xl {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-0-on-xl {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-xs-on-xl {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-sm-on-xl {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-md-on-xl {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-lg-on-xl {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-xl-on-xl {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-2xl-on-xl {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-3xl-on-xl {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-ml-4xl-on-xl {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-auto-on-xl {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-0-on-xl {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-xs-on-xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-sm-on-xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-md-on-xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-lg-on-xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-xl-on-xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-2xl-on-xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-3xl-on-xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-mx-4xl-on-xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-auto-on-xl {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-0-on-xl {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-xs-on-xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-sm-on-xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-md-on-xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-lg-on-xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-xl-on-xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-2xl-on-xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-3xl-on-xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-my-4xl-on-xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-auto-on-xl {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-0-on-xl {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-xs-on-xl {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-sm-on-xl {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-md-on-xl {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-lg-on-xl {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-xl-on-xl {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-2xl-on-xl {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-3xl-on-xl {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-p-4xl-on-xl {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-auto-on-xl {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-0-on-xl {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-xs-on-xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-sm-on-xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-md-on-xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-lg-on-xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-xl-on-xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-2xl-on-xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-3xl-on-xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pt-4xl-on-xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-auto-on-xl {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-0-on-xl {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-xs-on-xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-sm-on-xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-md-on-xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-lg-on-xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-xl-on-xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-2xl-on-xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-3xl-on-xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pr-4xl-on-xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-auto-on-xl {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-0-on-xl {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-xs-on-xl {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-sm-on-xl {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-md-on-xl {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-lg-on-xl {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-2xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-3xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pb-4xl-on-xl {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-auto-on-xl {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-0-on-xl {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-xs-on-xl {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-sm-on-xl {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-md-on-xl {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-lg-on-xl {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-xl-on-xl {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-2xl-on-xl {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-3xl-on-xl {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-pl-4xl-on-xl {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-auto-on-xl {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-0-on-xl {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-xs-on-xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-sm-on-xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-md-on-xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-lg-on-xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-xl-on-xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-2xl-on-xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-3xl-on-xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-px-4xl-on-xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-auto-on-xl {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-0-on-xl {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-xs-on-xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-sm-on-xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-md-on-xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-lg-on-xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-xl-on-xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-2xl-on-xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-3xl-on-xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1200px) {\n  .pf-u-py-4xl-on-xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-auto-on-2xl {\n    margin: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-0-on-2xl {\n    margin: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-xs-on-2xl {\n    margin: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-sm-on-2xl {\n    margin: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-md-on-2xl {\n    margin: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-lg-on-2xl {\n    margin: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-xl-on-2xl {\n    margin: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-2xl-on-2xl {\n    margin: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-3xl-on-2xl {\n    margin: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-m-4xl-on-2xl {\n    margin: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-auto-on-2xl {\n    margin-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-0-on-2xl {\n    margin-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-xs-on-2xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-sm-on-2xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-md-on-2xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-lg-on-2xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-xl-on-2xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-2xl-on-2xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-3xl-on-2xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mt-4xl-on-2xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-auto-on-2xl {\n    margin-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-0-on-2xl {\n    margin-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-xs-on-2xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-sm-on-2xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-md-on-2xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-lg-on-2xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-xl-on-2xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-2xl-on-2xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-3xl-on-2xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mr-4xl-on-2xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-auto-on-2xl {\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-0-on-2xl {\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-xs-on-2xl {\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-sm-on-2xl {\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-md-on-2xl {\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-lg-on-2xl {\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-2xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-3xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mb-4xl-on-2xl {\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-auto-on-2xl {\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-0-on-2xl {\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-xs-on-2xl {\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-sm-on-2xl {\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-md-on-2xl {\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-lg-on-2xl {\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-xl-on-2xl {\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-2xl-on-2xl {\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-3xl-on-2xl {\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-ml-4xl-on-2xl {\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-auto-on-2xl {\n    margin-right: auto !important;\n    margin-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-0-on-2xl {\n    margin-right: 0 !important;\n    margin-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-xs-on-2xl {\n    margin-right: var(--pf-global--spacer--xs) !important;\n    margin-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-sm-on-2xl {\n    margin-right: var(--pf-global--spacer--sm) !important;\n    margin-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-md-on-2xl {\n    margin-right: var(--pf-global--spacer--md) !important;\n    margin-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-lg-on-2xl {\n    margin-right: var(--pf-global--spacer--lg) !important;\n    margin-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-xl-on-2xl {\n    margin-right: var(--pf-global--spacer--xl) !important;\n    margin-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-2xl-on-2xl {\n    margin-right: var(--pf-global--spacer--2xl) !important;\n    margin-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-3xl-on-2xl {\n    margin-right: var(--pf-global--spacer--3xl) !important;\n    margin-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-mx-4xl-on-2xl {\n    margin-right: var(--pf-global--spacer--4xl) !important;\n    margin-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-auto-on-2xl {\n    margin-top: auto !important;\n    margin-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-0-on-2xl {\n    margin-top: 0 !important;\n    margin-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-xs-on-2xl {\n    margin-top: var(--pf-global--spacer--xs) !important;\n    margin-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-sm-on-2xl {\n    margin-top: var(--pf-global--spacer--sm) !important;\n    margin-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-md-on-2xl {\n    margin-top: var(--pf-global--spacer--md) !important;\n    margin-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-lg-on-2xl {\n    margin-top: var(--pf-global--spacer--lg) !important;\n    margin-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-xl-on-2xl {\n    margin-top: var(--pf-global--spacer--xl) !important;\n    margin-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-2xl-on-2xl {\n    margin-top: var(--pf-global--spacer--2xl) !important;\n    margin-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-3xl-on-2xl {\n    margin-top: var(--pf-global--spacer--3xl) !important;\n    margin-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-my-4xl-on-2xl {\n    margin-top: var(--pf-global--spacer--4xl) !important;\n    margin-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-auto-on-2xl {\n    padding: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-0-on-2xl {\n    padding: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-xs-on-2xl {\n    padding: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-sm-on-2xl {\n    padding: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-md-on-2xl {\n    padding: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-lg-on-2xl {\n    padding: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-xl-on-2xl {\n    padding: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-2xl-on-2xl {\n    padding: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-3xl-on-2xl {\n    padding: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-p-4xl-on-2xl {\n    padding: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-auto-on-2xl {\n    padding-top: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-0-on-2xl {\n    padding-top: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-xs-on-2xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-sm-on-2xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-md-on-2xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-lg-on-2xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-xl-on-2xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-2xl-on-2xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-3xl-on-2xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pt-4xl-on-2xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-auto-on-2xl {\n    padding-right: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-0-on-2xl {\n    padding-right: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-xs-on-2xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-sm-on-2xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-md-on-2xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-lg-on-2xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-xl-on-2xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-2xl-on-2xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-3xl-on-2xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pr-4xl-on-2xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-auto-on-2xl {\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-0-on-2xl {\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-xs-on-2xl {\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-sm-on-2xl {\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-md-on-2xl {\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-lg-on-2xl {\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-2xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-3xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pb-4xl-on-2xl {\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-auto-on-2xl {\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-0-on-2xl {\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-xs-on-2xl {\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-sm-on-2xl {\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-md-on-2xl {\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-lg-on-2xl {\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-xl-on-2xl {\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-2xl-on-2xl {\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-3xl-on-2xl {\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-pl-4xl-on-2xl {\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-auto-on-2xl {\n    padding-right: auto !important;\n    padding-left: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-0-on-2xl {\n    padding-right: 0 !important;\n    padding-left: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-xs-on-2xl {\n    padding-right: var(--pf-global--spacer--xs) !important;\n    padding-left: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-sm-on-2xl {\n    padding-right: var(--pf-global--spacer--sm) !important;\n    padding-left: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-md-on-2xl {\n    padding-right: var(--pf-global--spacer--md) !important;\n    padding-left: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-lg-on-2xl {\n    padding-right: var(--pf-global--spacer--lg) !important;\n    padding-left: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-xl-on-2xl {\n    padding-right: var(--pf-global--spacer--xl) !important;\n    padding-left: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-2xl-on-2xl {\n    padding-right: var(--pf-global--spacer--2xl) !important;\n    padding-left: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-3xl-on-2xl {\n    padding-right: var(--pf-global--spacer--3xl) !important;\n    padding-left: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-px-4xl-on-2xl {\n    padding-right: var(--pf-global--spacer--4xl) !important;\n    padding-left: var(--pf-global--spacer--4xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-auto-on-2xl {\n    padding-top: auto !important;\n    padding-bottom: auto !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-0-on-2xl {\n    padding-top: 0 !important;\n    padding-bottom: 0 !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-xs-on-2xl {\n    padding-top: var(--pf-global--spacer--xs) !important;\n    padding-bottom: var(--pf-global--spacer--xs) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-sm-on-2xl {\n    padding-top: var(--pf-global--spacer--sm) !important;\n    padding-bottom: var(--pf-global--spacer--sm) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-md-on-2xl {\n    padding-top: var(--pf-global--spacer--md) !important;\n    padding-bottom: var(--pf-global--spacer--md) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-lg-on-2xl {\n    padding-top: var(--pf-global--spacer--lg) !important;\n    padding-bottom: var(--pf-global--spacer--lg) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-xl-on-2xl {\n    padding-top: var(--pf-global--spacer--xl) !important;\n    padding-bottom: var(--pf-global--spacer--xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-2xl-on-2xl {\n    padding-top: var(--pf-global--spacer--2xl) !important;\n    padding-bottom: var(--pf-global--spacer--2xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-3xl-on-2xl {\n    padding-top: var(--pf-global--spacer--3xl) !important;\n    padding-bottom: var(--pf-global--spacer--3xl) !important;\n  }\n}\n\n@media screen and (min-width: 1450px) {\n  .pf-u-py-4xl-on-2xl {\n    padding-top: var(--pf-global--spacer--4xl) !important;\n    padding-bottom: var(--pf-global--spacer--4xl) !important;\n  }\n}";

// src/admin/providers/proxy/ProxyProviderForm.ts
var ProxyProviderFormPage = class extends BaseProviderForm {
  constructor() {
    super(...arguments);
    this.showHttpBasic = true;
    this.mode = ProxyMode.Proxy;
  }
  static get styles() {
    return [...super.styles, content_default, list_default, spacing_default];
  }
  async loadInstance(pk) {
    const provider = await new ProvidersApi(DEFAULT_CONFIG).providersProxyRetrieve({
      id: pk
    });
    this.showHttpBasic = first(provider.basicAuthEnabled, true);
    this.mode = first(provider.mode, ProxyMode.Proxy);
    return provider;
  }
  async send(data) {
    data.mode = this.mode;
    if (this.mode !== ProxyMode.ForwardDomain) {
      data.cookieDomain = "";
    }
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersProxyUpdate({
        id: this.instance.pk,
        proxyProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersProxyCreate({
        proxyProviderRequest: data
      });
    }
  }
  renderHttpBasic() {
    return ke`<ak-text-input
                name="basicAuthUserAttribute"
                label=${msg("HTTP-Basic Username Key")}
                value="${to(this.instance?.basicAuthUserAttribute)}"
                help=${msg(
      "User/Group Attribute used for the user part of the HTTP-Basic Header. If not set, the user's Email address is used."
    )}
            >
            </ak-text-input>

            <ak-text-input
                name="basicAuthPasswordAttribute"
                label=${msg("HTTP-Basic Password Key")}
                value="${to(this.instance?.basicAuthPasswordAttribute)}"
                help=${msg(
      "User/Group Attribute used for the password part of the HTTP-Basic Header."
    )}
            >
            </ak-text-input>`;
  }
  renderModeSelector() {
    const setMode = (ev) => {
      this.mode = ev.detail.value;
    };
    return ke`
            <ak-toggle-group value=${this.mode} @ak-toggle=${setMode}>
                <option value=${ProxyMode.Proxy}>${msg("Proxy")}</option>
                <option value=${ProxyMode.ForwardSingle}>${msg("Forward auth (single application)")}</option>
                <option value=${ProxyMode.ForwardDomain}>${msg("Forward auth (domain level)")}</option>
            </ak-toggle-group>
        `;
  }
  renderSettings() {
    switch (this.mode) {
      case ProxyMode.Proxy:
        return ke`<p class="pf-u-mb-xl">
                        ${msg(
          "This provider will behave like a transparent reverse-proxy, except requests must be authenticated. If your upstream application uses HTTPS, make sure to connect to the outpost using HTTPS as well."
        )}
                    </p>
                    <ak-form-element-horizontal
                        label=${msg("External host")}
                        ?required=${true}
                        name="externalHost"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.externalHost)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "The external URL you'll access the application at. Include any non-standard port."
        )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Internal host")}
                        ?required=${true}
                        name="internalHost"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.internalHost)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Upstream host that the requests are forwarded to.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="internalHostSslValidation">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.internalHostSslValidation, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Internal host SSL Validation")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg("Validate SSL Certificates of upstream servers.")}
                        </p>
                    </ak-form-element-horizontal>`;
      case ProxyMode.ForwardSingle:
        return ke`<p class="pf-u-mb-xl">
                        ${msg(
          "Use this provider with nginx's auth_request or traefik's forwardAuth. Each application/domain needs its own provider. Additionally, on each domain, /outpost.goauthentik.io must be routed to the outpost (when using a managed outpost, this is done for you)."
        )}
                    </p>
                    <ak-form-element-horizontal
                        label=${msg("External host")}
                        ?required=${true}
                        name="externalHost"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.externalHost)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "The external URL you'll access the application at. Include any non-standard port."
        )}
                        </p>
                    </ak-form-element-horizontal>`;
      case ProxyMode.ForwardDomain:
        return ke`<p class="pf-u-mb-xl">
                        ${msg(
          "Use this provider with nginx's auth_request or traefik's forwardAuth. Only a single provider is required per root domain. You can't do per-application authorization, but you don't have to create a provider for each application."
        )}
                    </p>
                    <div class="pf-u-mb-xl">
                        ${msg("An example setup can look like this:")}
                        <ul class="pf-c-list">
                            <li>${msg("authentik running on auth.example.com")}</li>
                            <li>${msg("app1 running on app1.example.com")}</li>
                        </ul>
                        ${msg(
          "In this case, you'd set the Authentication URL to auth.example.com and Cookie domain to example.com."
        )}
                    </div>
                    <ak-form-element-horizontal
                        label=${msg("Authentication URL")}
                        ?required=${true}
                        name="externalHost"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.externalHost, window.location.origin)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "The external URL you'll authenticate at. The authentik core server should be reachable under this URL."
        )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Cookie domain")}
                        name="cookieDomain"
                        ?required=${true}
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.cookieDomain)}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
          "Set this to the domain you wish the authentication to be valid for. Must be a parent domain of the URL above. If you're running applications as app1.domain.tld, app2.domain.tld, set this to 'domain.tld'."
        )}
                        </p>
                    </ak-form-element-horizontal>`;
      case ProxyMode.UnknownDefaultOpenApi:
        return ke`<p>${msg("Unknown proxy mode")}</p>`;
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication flow")}
                ?required=${false}
                name="authenticationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authenticationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when a user access this provider and is not authenticated.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authorization flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${this.instance?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>

            <div class="pf-c-card pf-m-selectable pf-m-selected">
                <div class="pf-c-card__body">${this.renderModeSelector()}</div>
                <div class="pf-c-card__footer">${this.renderSettings()}</div>
            </div>
            <ak-form-element-horizontal label=${msg("Token validity")} name="accessTokenValidity">
                <input
                    type="text"
                    value="${first(this.instance?.accessTokenValidity, "hours=24")}"
                    class="pf-c-form-control"
                />
                <p class="pf-c-form__helper-text">
                    ${msg("Configure how long tokens are valid for.")}
                </p>
                <ak-utils-time-delta-help></ak-utils-time-delta-help>
            </ak-form-element-horizontal>

            <ak-form-group>
                <span slot="header">${msg("Advanced protocol settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("Certificate")} name="certificate">
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.certificate}
                        ></ak-crypto-certificate-search>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Additional scopes")}
                        name="propertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${proxyPropertyMappingsProvider}
                            .selector=${makeProxyPropertyMappingsSelector(
      this.instance?.propertyMappings
    )}
                            available-label="${msg("Available Scopes")}"
                            selected-label="${msg("Selected Scopes")}"
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Additional scope mappings, which are passed to the proxy.")}
                        </p>
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal
                        label="${this.mode === ProxyMode.ForwardDomain ? msg("Unauthenticated URLs") : msg("Unauthenticated Paths")}"
                        name="skipPathRegex"
                    >
                        <textarea class="pf-c-form-control">
${this.instance?.skipPathRegex}</textarea
                        >
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Regular expressions for which authentication is not required. Each new line is interpreted as a new expression."
    )}
                        </p>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When using proxy or forward auth (single application) mode, the requested URL Path is checked against the regular expressions. When using forward auth (domain mode), the full requested URL including scheme and host is matched against the regular expressions."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group>
                <span slot="header">${msg("Authentication settings")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="interceptHeaderAuth">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.interceptHeaderAuth, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Intercept header authentication")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When enabled, authentik will intercept the Authorization header to authenticate the request."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal name="basicAuthEnabled">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.basicAuthEnabled, false)}
                                @change=${(ev) => {
      const el = ev.target;
      this.showHttpBasic = el.checked;
    }}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Send HTTP-Basic Authentication")}</span
                            >
                        </label>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Send a custom HTTP-Basic Authentication header based on values from authentik."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    ${this.showHttpBasic ? this.renderHttpBasic() : ke``}
                    <ak-form-element-horizontal
                        label=${msg("Trusted OIDC Sources")}
                        name="jwksSources"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${oauth2SourcesProvider}
                            .selector=${makeSourceSelector(this.instance?.jwksSources)}
                            available-label=${msg("Available Sources")}
                            selected-label=${msg("Selected Sources")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "JWTs signed by certificates configured in the selected sources can be used to authenticate to this provider."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], ProxyProviderFormPage.prototype, "showHttpBasic", 2);
__decorateClass([
  r()
], ProxyProviderFormPage.prototype, "mode", 2);
ProxyProviderFormPage = __decorateClass([
  t("ak-provider-proxy-form")
], ProxyProviderFormPage);

// src/admin/providers/saml/SAMLProviderForm.ts
async function samlPropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderSamlList({
    ordering: "saml_name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((m) => [m.pk, m.name, m.name, m])
  };
}
function makeSAMLPropertyMappingsSelector(instanceMappings) {
  const localMappings = instanceMappings ? new Set(instanceMappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, mapping]) => mapping?.managed?.startsWith("goauthentik.io/providers/saml");
}
var SAMLProviderFormPage = class extends BaseProviderForm {
  constructor() {
    super(...arguments);
    this.hasSigningKp = false;
  }
  async loadInstance(pk) {
    const provider = await new ProvidersApi(DEFAULT_CONFIG).providersSamlRetrieve({
      id: pk
    });
    this.hasSigningKp = !!provider.signingKp;
    return provider;
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersSamlUpdate({
        id: this.instance.pk,
        sAMLProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersSamlCreate({
        sAMLProviderRequest: data
      });
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication flow")}
                ?required=${false}
                name="authenticationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authenticationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when a user access this provider and is not authenticated.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authorization flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${this.instance?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("ACS URL")}
                        ?required=${true}
                        name="acsUrl"
                    >
                        <input
                            type="text"
                            value="${to(this.instance?.acsUrl)}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Issuer")}
                        ?required=${true}
                        name="issuer"
                    >
                        <input
                            type="text"
                            value="${this.instance?.issuer || "authentik"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">${msg("Also known as EntityID.")}</p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Service Provider Binding")}
                        ?required=${true}
                        name="spBinding"
                    >
                        <ak-radio
                            .options=${[
      {
        label: msg("Redirect"),
        value: SpBindingEnum.Redirect,
        default: true
      },
      {
        label: msg("Post"),
        value: SpBindingEnum.Post
      }
    ]}
                            .value=${this.instance?.spBinding}
                        >
                        </ak-radio>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Determines how authentik sends the response back to the Service Provider."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Audience")} name="audience">
                        <input
                            type="text"
                            value="${to(this.instance?.audience)}"
                            class="pf-c-form-control"
                        />
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>

            <ak-form-group>
                <span slot="header"> ${msg("Advanced protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Signing Certificate")}
                        name="signingKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.signingKp}
                            @input=${(ev) => {
      const target = ev.target;
      if (!target) return;
      this.hasSigningKp = !!target.selectedKeypair;
    }}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Certificate used to sign outgoing Responses going to the Service Provider."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    ${this.hasSigningKp ? ke` <ak-form-element-horizontal name="signAssertion">
                                  <label class="pf-c-switch">
                                      <input
                                          class="pf-c-switch__input"
                                          type="checkbox"
                                          ?checked=${first(this.instance?.signAssertion, true)}
                                      />
                                      <span class="pf-c-switch__toggle">
                                          <span class="pf-c-switch__toggle-icon">
                                              <i class="fas fa-check" aria-hidden="true"></i>
                                          </span>
                                      </span>
                                      <span class="pf-c-switch__label"
                                          >${msg("Sign assertions")}</span
                                      >
                                  </label>
                                  <p class="pf-c-form__helper-text">
                                      ${msg(
      "When enabled, the assertion element of the SAML response will be signed."
    )}
                                  </p>
                              </ak-form-element-horizontal>
                              <ak-form-element-horizontal name="signResponse">
                                  <label class="pf-c-switch">
                                      <input
                                          class="pf-c-switch__input"
                                          type="checkbox"
                                          ?checked=${first(this.instance?.signResponse, false)}
                                      />
                                      <span class="pf-c-switch__toggle">
                                          <span class="pf-c-switch__toggle-icon">
                                              <i class="fas fa-check" aria-hidden="true"></i>
                                          </span>
                                      </span>
                                      <span class="pf-c-switch__label"
                                          >${msg("Sign responses")}</span
                                      >
                                  </label>
                                  <p class="pf-c-form__helper-text">
                                      ${msg(
      "When enabled, the assertion element of the SAML response will be signed."
    )}
                                  </p>
                              </ak-form-element-horizontal>` : D}
                    <ak-form-element-horizontal
                        label=${msg("Verification Certificate")}
                        name="verificationKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.verificationKp}
                            nokey
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When selected, incoming assertion's Signatures will be validated against this certificate. To allow unsigned Requests, leave on default."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Encryption Certificate")}
                        name="encryptionKp"
                    >
                        <ak-crypto-certificate-search
                            .certificate=${this.instance?.encryptionKp}
                        ></ak-crypto-certificate-search>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When selected, assertions will be encrypted using this keypair."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Property mappings")}
                        name="propertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${samlPropertyMappingsProvider}
                            .selector=${makeSAMLPropertyMappingsSelector(
      this.instance?.propertyMappings
    )}
                            available-label=${msg("Available User Property Mappings")}
                            selected-label=${msg("Selected User Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("NameID Property Mapping")}
                        name="nameIdMapping"
                    >
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "saml_name"
      };
      if (query !== void 0) {
        args.search = query;
      }
      const items = await new PropertymappingsApi(
        DEFAULT_CONFIG
      ).propertymappingsProviderSamlList(args);
      return items.results;
    }}
                            .renderElement=${(item) => {
      return item.name;
    }}
                            .value=${(item) => {
      return item?.pk;
    }}
                            .selected=${(item) => {
      return this.instance?.nameIdMapping === item.pk;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Configure how the NameID value will be created. When left empty, the NameIDPolicy of the incoming request will be respected."
    )}
                        </p>
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal
                        label=${msg("Assertion valid not before")}
                        ?required=${true}
                        name="assertionValidNotBefore"
                    >
                        <input
                            type="text"
                            value="${this.instance?.assertionValidNotBefore || "minutes=-5"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Configure the maximum allowed time drift for an assertion.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Assertion valid not on or after")}
                        ?required=${true}
                        name="assertionValidNotOnOrAfter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.assertionValidNotOnOrAfter || "minutes=5"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Assertion not valid on or after current time + this value.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Session valid not on or after")}
                        ?required=${true}
                        name="sessionValidNotOnOrAfter"
                    >
                        <input
                            type="text"
                            value="${this.instance?.sessionValidNotOnOrAfter || "minutes=86400"}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Session not valid on or after current time + this value.")}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Default relay state")}
                        ?required=${true}
                        name="defaultRelayState"
                    >
                        <input
                            type="text"
                            value="${this.instance?.defaultRelayState || ""}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "When using IDP-initiated logins, the relay state will be set to this value."
    )}
                        </p>
                        <ak-utils-time-delta-help></ak-utils-time-delta-help>
                    </ak-form-element-horizontal>

                    <ak-form-element-horizontal
                        label=${msg("Digest algorithm")}
                        ?required=${true}
                        name="digestAlgorithm"
                    >
                        <ak-radio
                            .options=${digestAlgorithmOptions}
                            .value=${this.instance?.digestAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Signature algorithm")}
                        ?required=${true}
                        name="signatureAlgorithm"
                    >
                        <ak-radio
                            .options=${signatureAlgorithmOptions}
                            .value=${this.instance?.signatureAlgorithm}
                        >
                        </ak-radio>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
__decorateClass([
  r()
], SAMLProviderFormPage.prototype, "hasSigningKp", 2);
SAMLProviderFormPage = __decorateClass([
  t("ak-provider-saml-form")
], SAMLProviderFormPage);

// src/admin/providers/google_workspace/GoogleWorkspaceProviderPropertyMappings.ts
async function googleWorkspacePropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderGoogleWorkspaceList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((scope) => [scope.pk, scope.name, scope.name, scope])
  };
}
function makeGoogleWorkspacePropertyMappingsSelector(instanceMappings, defaultSelection) {
  const localMappings = instanceMappings ? new Set(instanceMappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, scope]) => scope?.managed === defaultSelection;
}

// src/admin/providers/google_workspace/GoogleWorkspaceProviderForm.ts
var GoogleWorkspaceProviderFormPage = class extends BaseProviderForm {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersGoogleWorkspaceRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersGoogleWorkspaceUpdate({
        id: this.instance.pk,
        googleWorkspaceProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersGoogleWorkspaceCreate({
        googleWorkspaceProviderRequest: data
      });
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Credentials")}
                        ?required=${true}
                        name="credentials"
                    >
                        <ak-codemirror
                            mode=${"javascript" /* JavaScript */}
                            .value="${first(this.instance?.credentials, {})}"
                        ></ak-codemirror>
                        <p class="pf-c-form__helper-text">
                            ${msg("Google Cloud credentials file.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Delegated Subject")}
                        ?required=${true}
                        name="delegatedSubject"
                    >
                        <input
                            type="email"
                            value="${first(this.instance?.delegatedSubject, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Email address of the user the actions of authentik will be delegated to."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Default group email domain")}
                        ?required=${true}
                        name="defaultGroupEmailDomain"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.defaultGroupEmailDomain, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Default domain that is used to generate a group's email address. Can be customized using property mappings."
    )}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-radio-input
                        name="userDeleteAction"
                        label=${msg("User deletion action")}
                        required
                        .options=${[
      {
        label: msg("Delete"),
        value: OutgoingSyncDeleteAction.Delete,
        default: true,
        description: ke`${msg("User is deleted")}`
      },
      {
        label: msg("Suspend"),
        value: OutgoingSyncDeleteAction.Suspend,
        description: ke`${msg(
          "User is suspended, and connection to user in authentik is removed."
        )}`
      },
      {
        label: msg("Do Nothing"),
        value: OutgoingSyncDeleteAction.DoNothing,
        description: ke`${msg(
          "The connection is removed but the user is not modified"
        )}`
      }
    ]}
                        .value=${this.instance?.userDeleteAction}
                        help=${msg("Determines what authentik will do when a User is deleted.")}
                    >
                    </ak-radio-input>
                    <ak-radio-input
                        name="groupDeleteAction"
                        label=${msg("Group deletion action")}
                        required
                        .options=${[
      {
        label: msg("Delete"),
        value: OutgoingSyncDeleteAction.Delete,
        default: true,
        description: ke`${msg("Group is deleted")}`
      },
      {
        label: msg("Do Nothing"),
        value: OutgoingSyncDeleteAction.DoNothing,
        description: ke`${msg(
          "The connection is removed but the group is not modified"
        )}`
      }
    ]}
                        .value=${this.instance?.groupDeleteAction}
                        help=${msg("Determines what authentik will do when a Group is deleted.")}
                    >
                    </ak-radio-input>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header">${msg("User filtering")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="excludeUsersServiceAccount">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.excludeUsersServiceAccount, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Exclude service accounts")}</span
                            >
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Group")} name="filterGroup">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name",
        includeUsers: false
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group ? group.pk : void 0;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.filterGroup;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Only sync users within the selected group.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="propertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${googleWorkspacePropertyMappingsProvider}
                            .selector=${makeGoogleWorkspacePropertyMappingsSelector(
      this.instance?.propertyMappings,
      "goauthentik.io/providers/google_workspace/user"
    )}
                            available-label=${msg("Available Property Mappings")}
                            selected-label=${msg("Selected Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to user mapping.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="propertyMappingsGroup"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${googleWorkspacePropertyMappingsProvider}
                            .selector=${makeGoogleWorkspacePropertyMappingsSelector(
      this.instance?.propertyMappingsGroup,
      "goauthentik.io/providers/google_workspace/group"
    )}
                            available-label=${msg("Available Property Mappings")}
                            selected-label=${msg("Selected Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
GoogleWorkspaceProviderFormPage = __decorateClass([
  t("ak-provider-google-workspace-form")
], GoogleWorkspaceProviderFormPage);

// src/admin/providers/microsoft_entra/MicrosoftEntraProviderPropertyMappings.ts
async function microsoftEntraPropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderMicrosoftEntraList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((scope) => [scope.pk, scope.name, scope.name, scope])
  };
}
function makeMicrosoftEntraPropertyMappingsSelector(instanceMappings, defaultSelection) {
  const localMappings = instanceMappings ? new Set(instanceMappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, scope]) => scope?.managed === defaultSelection;
}

// src/admin/providers/microsoft_entra/MicrosoftEntraProviderForm.ts
var MicrosoftEntraProviderFormPage = class extends BaseProviderForm {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersMicrosoftEntraRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersMicrosoftEntraUpdate({
        id: this.instance.pk,
        microsoftEntraProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersMicrosoftEntraCreate({
        microsoftEntraProviderRequest: data
      });
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Client ID")}
                        ?required=${true}
                        name="clientId"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.clientId, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Client ID for the app registration.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Client Secret")}
                        ?required=${true}
                        name="clientSecret"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.clientSecret, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("Client secret for the app registration.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Tenant ID")}
                        ?required=${true}
                        name="tenantId"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.tenantId, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("ID of the tenant accounts will be synced into.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-radio-input
                        name="userDeleteAction"
                        label=${msg("User deletion action")}
                        required
                        .options=${[
      {
        label: msg("Delete"),
        value: OutgoingSyncDeleteAction.Delete,
        default: true,
        description: ke`${msg("User is deleted")}`
      },
      {
        label: msg("Do Nothing"),
        value: OutgoingSyncDeleteAction.DoNothing,
        description: ke`${msg(
          "The connection is removed but the user is not modified"
        )}`
      }
    ]}
                        .value=${this.instance?.userDeleteAction}
                        help=${msg("Determines what authentik will do when a User is deleted.")}
                    >
                    </ak-radio-input>
                    <ak-radio-input
                        name="groupDeleteAction"
                        label=${msg("Group deletion action")}
                        required
                        .options=${[
      {
        label: msg("Delete"),
        value: OutgoingSyncDeleteAction.Delete,
        default: true,
        description: ke`${msg("Group is deleted")}`
      },
      {
        label: msg("Do Nothing"),
        value: OutgoingSyncDeleteAction.DoNothing,
        description: ke`${msg(
          "The connection is removed but the group is not modified"
        )}`
      }
    ]}
                        .value=${this.instance?.groupDeleteAction}
                        help=${msg("Determines what authentik will do when a Group is deleted.")}
                    >
                    </ak-radio-input>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header">${msg("User filtering")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="excludeUsersServiceAccount">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.excludeUsersServiceAccount, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Exclude service accounts")}</span
                            >
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Group")} name="filterGroup">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name",
        includeUsers: false
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group ? group.pk : void 0;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.filterGroup;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Only sync users within the selected group.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="propertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${microsoftEntraPropertyMappingsProvider}
                            .selector=${makeMicrosoftEntraPropertyMappingsSelector(
      this.instance?.propertyMappings,
      "goauthentik.io/providers/microsoft_entra/user"
    )}
                            available-label=${msg("Available Property Mappings")}
                            selected-label=${msg("Selected Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to user mapping.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="propertyMappingsGroup"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${microsoftEntraPropertyMappingsProvider}
                            .selector=${makeMicrosoftEntraPropertyMappingsSelector(
      this.instance?.propertyMappingsGroup,
      "goauthentik.io/providers/microsoft_entra/group"
    )}
                            available-label=${msg("Available Property Mappings")}
                            selected-label=${msg("Selected Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
MicrosoftEntraProviderFormPage = __decorateClass([
  t("ak-provider-microsoft-entra-form")
], MicrosoftEntraProviderFormPage);

// src/admin/providers/rac/RACProviderForm.ts
var RACProviderFormPage = class extends ModelForm {
  async loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersRacRetrieve({
      id: pk
    });
  }
  getSuccessMessage() {
    if (this.instance) {
      return msg("Successfully updated provider.");
    } else {
      return msg("Successfully created provider.");
    }
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersRacUpdate({
        id: this.instance.pk,
        rACProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersRacCreate({
        rACProviderRequest: data
      });
    }
  }
  renderForm() {
    return ke`
            <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>

            <ak-form-element-horizontal
                name="authorizationFlow"
                label=${msg("Authorization flow")}
                ?required=${true}
            >
                <ak-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authorization}
                    .currentFlow=${this.instance?.authorizationFlow}
                    required
                ></ak-flow-search>
                <p class="pf-c-form__helper-text">
                    ${msg("Flow used when authorizing this provider.")}
                </p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Connection expiry")}
                ?required=${true}
                name="connectionExpiry"
            >
                <input
                    type="text"
                    value="${first(this.instance?.connectionExpiry, "hours=8")}"
                    class="pf-c-form-control"
                    required
                />
                <p class="pf-c-form__helper-text">
                    ${msg(
      "Determines how long a session lasts before being disconnected and requiring re-authorization."
    )}
                </p>
                <ak-utils-time-delta-help></ak-utils-time-delta-help>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="deleteTokenOnDisconnect">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.deleteTokenOnDisconnect, false)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label"
                        >${msg("Delete authorization on disconnect")}</span
                    >
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When enabled, connection authorizations will be deleted when a client disconnects. This will force clients with flaky internet connections to re-authorize the endpoint."
    )}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Property mappings")}
                        name="propertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${racPropertyMappingsProvider}
                            .selector=${makeRACPropertyMappingsSelector(
      this.instance?.propertyMappings
    )}
                            available-label="${msg("Available Property Mappings")}"
                            selected-label="${msg("Selected Property Mappings")}"
                        ></ak-dual-select-dynamic-selected>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Settings")} name="settings">
                        <ak-codemirror
                            mode="yaml"
                            value="${browser_default.stringify(first(this.instance?.settings, {}))}"
                        >
                        </ak-codemirror>
                        <p class="pf-c-form__helper-text">${msg("Connection settings.")}</p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
        `;
  }
};
RACProviderFormPage = __decorateClass([
  t("ak-provider-rac-form")
], RACProviderFormPage);

// src/admin/providers/radius/RadiusProviderForm.ts
async function radiusPropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderRadiusList({
    ordering: "name",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((m) => [m.pk, m.name, m.name, m])
  };
}
function makeRadiusPropertyMappingsSelector(instanceMappings) {
  const localMappings = instanceMappings ? new Set(instanceMappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, _]) => [];
}
var RadiusProviderFormPage = class extends WithBrandConfig(BaseProviderForm) {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersRadiusRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersRadiusUpdate({
        id: this.instance.pk,
        radiusProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersRadiusCreate({
        radiusProviderRequest: data
      });
    }
  }
  // All Provider objects have an Authorization flow, but not all providers have an Authentication
  // flow. Radius needs only one field, but it is not the Authorization field, it is an
  // Authentication field. So, yeah, we're using the authorization field to store the
  // authentication information, which is why the ak-branded-flow-search call down there looks so
  // weird-- we're looking up Authentication flows, but we're storing them in the Authorization
  // field of the target Provider.
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-element-horizontal
                label=${msg("Authentication flow")}
                ?required=${true}
                name="authorizationFlow"
            >
                <ak-branded-flow-search
                    flowType=${FlowsInstancesListDesignationEnum.Authentication}
                    .currentFlow=${this.instance?.authorizationFlow}
                    .brandFlow=${this.brand?.flowAuthentication}
                    required
                ></ak-branded-flow-search>
                <p class="pf-c-form__helper-text">${msg("Flow used for users to authenticate.")}</p>
            </ak-form-element-horizontal>
            <ak-form-element-horizontal name="mfaSupport">
                <label class="pf-c-switch">
                    <input
                        class="pf-c-switch__input"
                        type="checkbox"
                        ?checked=${first(this.instance?.mfaSupport, true)}
                    />
                    <span class="pf-c-switch__toggle">
                        <span class="pf-c-switch__toggle-icon">
                            <i class="fas fa-check" aria-hidden="true"></i>
                        </span>
                    </span>
                    <span class="pf-c-switch__label">${msg("Code-based MFA Support")}</span>
                </label>
                <p class="pf-c-form__helper-text">
                    ${msg(
      "When enabled, code-based multi-factor authentication can be used by appending a semicolon and the TOTP code to the password. This should only be enabled if all users that will bind to this provider have a TOTP device configured, as otherwise a password may incorrectly be rejected if it contains a semicolon."
    )}
                </p>
            </ak-form-element-horizontal>

            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("Shared secret")}
                        ?required=${true}
                        name="sharedSecret"
                    >
                        <input
                            type="text"
                            value="${first(
      this.instance?.sharedSecret,
      randomString(128, ascii_letters + digits)
    )}"
                            class="pf-c-form-control"
                            required
                        />
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Client Networks")}
                        ?required=${true}
                        name="clientNetworks"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.clientNetworks, "0.0.0.0/0, ::/0")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(`List of CIDRs (comma-seperated) that clients can connect from. A more specific
                            CIDR will match before a looser one. Clients connecting from a non-specified CIDR
                            will be dropped.`)}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Property mappings")}
                        name="propertyMappings"
                    >
                        <ak-dual-select-dynamic-selected
                            .provider=${radiusPropertyMappingsProvider}
                            .selector=${makeRadiusPropertyMappingsSelector(
      this.instance?.propertyMappings
    )}
                            available-label=${msg("Available Property Mappings")}
                            selected-label=${msg("Selected Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
RadiusProviderFormPage = __decorateClass([
  t("ak-provider-radius-form")
], RadiusProviderFormPage);

// src/admin/providers/scim/SCIMProviderForm.ts
async function scimPropertyMappingsProvider(page = 1, search = "") {
  const propertyMappings = await new PropertymappingsApi(
    DEFAULT_CONFIG
  ).propertymappingsProviderScimList({
    ordering: "managed",
    pageSize: 20,
    search: search.trim(),
    page
  });
  return {
    pagination: propertyMappings.pagination,
    options: propertyMappings.results.map((m) => [m.pk, m.name, m.name, m])
  };
}
function makeSCIMPropertyMappingsSelector(instanceMappings, defaultSelected) {
  const localMappings = instanceMappings ? new Set(instanceMappings) : void 0;
  return localMappings ? ([pk, _]) => localMappings.has(pk) : ([_0, _1, _2, mapping]) => mapping?.managed === defaultSelected;
}
var SCIMProviderFormPage = class extends BaseProviderForm {
  loadInstance(pk) {
    return new ProvidersApi(DEFAULT_CONFIG).providersScimRetrieve({
      id: pk
    });
  }
  async send(data) {
    if (this.instance) {
      return new ProvidersApi(DEFAULT_CONFIG).providersScimUpdate({
        id: this.instance.pk,
        sCIMProviderRequest: data
      });
    } else {
      return new ProvidersApi(DEFAULT_CONFIG).providersScimCreate({
        sCIMProviderRequest: data
      });
    }
  }
  renderForm() {
    return ke` <ak-form-element-horizontal label=${msg("Name")} ?required=${true} name="name">
                <input
                    type="text"
                    value="${to(this.instance?.name)}"
                    class="pf-c-form-control"
                    required
                />
            </ak-form-element-horizontal>
            <ak-form-group .expanded=${true}>
                <span slot="header"> ${msg("Protocol settings")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal label=${msg("URL")} ?required=${true} name="url">
                        <input
                            type="text"
                            value="${first(this.instance?.url, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg("SCIM base url, usually ends in /v2.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Token")}
                        ?required=${true}
                        name="token"
                    >
                        <input
                            type="text"
                            value="${first(this.instance?.token, "")}"
                            class="pf-c-form-control"
                            required
                        />
                        <p class="pf-c-form__helper-text">
                            ${msg(
      "Token to authenticate with. Currently only bearer authentication is supported."
    )}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header">${msg("User filtering")}</span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal name="excludeUsersServiceAccount">
                        <label class="pf-c-switch">
                            <input
                                class="pf-c-switch__input"
                                type="checkbox"
                                ?checked=${first(this.instance?.excludeUsersServiceAccount, true)}
                            />
                            <span class="pf-c-switch__toggle">
                                <span class="pf-c-switch__toggle-icon">
                                    <i class="fas fa-check" aria-hidden="true"></i>
                                </span>
                            </span>
                            <span class="pf-c-switch__label"
                                >${msg("Exclude service accounts")}</span
                            >
                        </label>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal label=${msg("Group")} name="filterGroup">
                        <ak-search-select
                            .fetchObjects=${async (query) => {
      const args = {
        ordering: "name",
        includeUsers: false
      };
      if (query !== void 0) {
        args.search = query;
      }
      const groups = await new CoreApi(DEFAULT_CONFIG).coreGroupsList(
        args
      );
      return groups.results;
    }}
                            .renderElement=${(group) => {
      return group.name;
    }}
                            .value=${(group) => {
      return group ? group.pk : void 0;
    }}
                            .selected=${(group) => {
      return group.pk === this.instance?.filterGroup;
    }}
                            ?blankable=${true}
                        >
                        </ak-search-select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Only sync users within the selected group.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>
            <ak-form-group ?expanded=${true}>
                <span slot="header"> ${msg("Attribute mapping")} </span>
                <div slot="body" class="pf-c-form">
                    <ak-form-element-horizontal
                        label=${msg("User Property Mappings")}
                        name="propertyMappings">
                        <ak-dual-select-dynamic-selected
                            .provider=${scimPropertyMappingsProvider}
                            .selector=${makeSCIMPropertyMappingsSelector(
      this.instance?.propertyMappings,
      "goauthentik.io/providers/scim/user"
    )}
                            available-label=${msg("Available User Property Mappings")}
                            selected-label=${msg("Selected User Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                        </select>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to user mapping.")}
                        </p>
                    </ak-form-element-horizontal>
                    <ak-form-element-horizontal
                        label=${msg("Group Property Mappings")}
                        name="propertyMappingsGroup">
                        <ak-dual-select-dynamic-selected
                            .provider=${scimPropertyMappingsProvider}
                            .selector=${makeSCIMPropertyMappingsSelector(
      this.instance?.propertyMappingsGroup,
      "goauthentik.io/providers/scim/group"
    )}
                            available-label=${msg("Available Group Property Mappings")}
                            selected-label=${msg("Selected Group Property Mappings")}
                        ></ak-dual-select-dynamic-selected>
                        <p class="pf-c-form__helper-text">
                            ${msg("Property mappings used to group creation.")}
                        </p>
                    </ak-form-element-horizontal>
                </div>
            </ak-form-group>`;
  }
};
SCIMProviderFormPage = __decorateClass([
  t("ak-provider-scim-form")
], SCIMProviderFormPage);

// src/admin/common/ak-flow-search/ak-flow-search-no-default.ts
var AkFlowSearchNoDefault = class extends FlowSearch {
  render() {
    return ke`
            <ak-search-select
                .fetchObjects=${this.fetchObjects}
                .renderElement=${renderElement}
                .renderDescription=${renderDescription}
                .value=${getFlowValue}
                @ak-change=${this.handleSearchUpdate}
                ?blankable=${!this.required}
            >
            </ak-search-select>
        `;
  }
};
AkFlowSearchNoDefault = __decorateClass([
  t("ak-flow-search-no-default")
], AkFlowSearchNoDefault);
//# sourceMappingURL=chunk-QVNDK2YP.js.map
